package model

import (
	"applet/app/utils/cache"
	"fmt"
	jsoniter "github.com/json-iterator/go"
	"xorm.io/xorm"
)

var Json = jsoniter.ConfigCompatibleWithStandardLibrary

func (set *FbPaySet) init(engine *xorm.Engine) error {
	_, err := engine.Insert(set)
	return err
}

func (set *FbPaySet) Get(engine *xorm.Engine) error {
	exist, err := engine.IsTableExist(set)
	if err != nil {
		return err
	}
	if !exist {
		if err := engine.CreateTables(set); err != nil {
			return err
		}
	}
	if err != nil {
		return err
	}
	get, err := engine.Get(set)
	if err != nil {
		return err
	}
	if !get {
		err := set.init(engine)
		if err != nil {
			return err
		}
	}
	return nil
}

func (set *FbPaySet) Update(engine *xorm.Engine, cols []string) error {
	if len(cols) == 0 {
		_, err := engine.ID(set.Id).AllCols().Update(set)
		if err != nil {
			return err
		}
		return nil
	} else {
		_, err := engine.ID(set.Id).Cols(cols...).Update(set)
		if err != nil {
			return err
		}
		return nil
	}
}

func (set *FbPaySet) ToRedis(mid string) error {
	marshalToString, err := Json.MarshalToString(set)
	if err != nil {
		return err
	}
	key := fmt.Sprintf("%s:fb_pay_setting", mid)
	_, err = cache.SetEx(key, marshalToString, 39528000) // 半年
	if err != nil {
		return err
	}
	return nil
}

func (set *FbPaySet) GetByRedis(mid string) bool {
	key := fmt.Sprintf("%s:fb_pay_setting", mid)
	marshalString, _ := cache.GetString(key)
	if marshalString == "" || len(marshalString) < 10 {
		return false
	}
	err := Json.UnmarshalFromString(marshalString, set)
	if err != nil {
		return false
	}
	return true
}
